==> openjdk13-13.0.13_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fil.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fil extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AMD", "AMD" },
            { "AOA", "AOA" },
            { "AZN", "AZN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BWP", "BWP" },
            { "CDF", "CDF" },
            { "CVE", "CVE" },
            { "DJF", "DJF" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "IQD", "IQD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KMF", "KMF" },
            { "KWD", "KWD" },
            { "KZT", "KZT" },
            { "LBP", "LBP" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MGA", "MGA" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MWK", "MWK" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "OMR", "OMR" },
            { "PGK", "PGK" },
            { "PHP", "\u20b1" },
            { "QAR", "QAR" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TZS", "TZS" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "UZS", "UZS" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "United Arab Emirates Dirham" },
            { "afn", "Afghan Afghani" },
            { "all", "Albanian Lek" },
            { "amd", "Armenian Dram" },
            { "ang", "Antillean Guilder ng Netherlands" },
            { "aoa", "Angolan Kwanza" },
            { "ars", "Piso ng Argentina" },
            { "aud", "Dolyar ng Australya" },
            { "awg", "Florin ng Aruba" },
            { "azn", "Azerbaijani Manat" },
            { "bam", "Bosnia-Herzegovina Convertible Mark" },
            { "bbd", "Dolyar ng Barbados" },
            { "bdt", "Bangladeshi Taka" },
            { "bgn", "Bulgarian Lev" },
            { "bhd", "Bahraini Dinar" },
            { "bif", "Burundian Franc" },
            { "bmd", "Dolyar ng Bermuda" },
            { "bnd", "Dolyar ng Brunei" },
            { "bob", "Boliviano ng Bolivia" },
            { "brl", "Real ng Barzil" },
            { "bsd", "Dolyar ng Bahamas" },
            { "btn", "Bhutanese Ngultrum" },
            { "bwp", "Botswanan Pula" },
            { "byn", "Belarusian Ruble" },
            { "byr", "Belarusian Ruble (2000\u20132016)" },
            { "bzd", "Dolyar ng Belize" },
            { "cad", "Dolyar ng Canada" },
            { "cdf", "Congolese Franc" },
            { "chf", "Swiss Franc" },
            { "clp", "Piso ng Chile" },
            { "cny", "Chinese Yuan" },
            { "cop", "Piso ng Colombia" },
            { "crc", "Col\u00f3n ng Costa Rica" },
            { "cuc", "Convertible na Piso ng Cuba" },
            { "cup", "Piso ng Cuba" },
            { "cve", "Cape Verdean Escudo" },
            { "czk", "Czech Republic Koruna" },
            { "dem", "Deutsche Marks" },
            { "djf", "Djiboutian Franc" },
            { "dkk", "Danish Krone" },
            { "dop", "Piso ng Dominican" },
            { "dzd", "Algerian Dinar" },
            { "eek", "Estonian Kroon" },
            { "egp", "Egyptian Pound" },
            { "ern", "Eritrean Nakfa" },
            { "etb", "Ethiopian Birr" },
            { "eur", "Euro" },
            { "fjd", "Dolyar ng Fiji" },
            { "fkp", "Pound ng Falkland Islands" },
            { "frf", "French Franc" },
            { "gbp", "British Pound" },
            { "gel", "Georgian Lari" },
            { "ghs", "Ghanaian Cedi" },
            { "gip", "Gibraltar Pound" },
            { "gmd", "Gambian Dalasi" },
            { "gnf", "Guinean Franc" },
            { "gtq", "Quetzal ng Guatemala" },
            { "gyd", "Dolyar ng Guyanese" },
            { "hkd", "Dolyar ng Hong Kong" },
            { "hnl", "Lempira ng Honduras" },
            { "hrk", "Croatian Kuna" },
            { "htg", "Gourde ng Haiti" },
            { "huf", "Hungarian Forint" },
            { "idr", "Indonesian Rupiah" },
            { "ils", "Israeli New Sheqel" },
            { "inr", "Indian Rupee" },
            { "iqd", "Iraqi Dinar" },
            { "irr", "Iranian Rial" },
            { "isk", "Icelandic Kr\u00f3na" },
            { "jmd", "Dolyar ng Jamaica" },
            { "jod", "Jordanian Dinar" },
            { "jpy", "Japanese Yen" },
            { "kes", "Kenyan Shilling" },
            { "kgs", "Kyrgystani Som" },
            { "khr", "Cambodian Riel" },
            { "kmf", "Comorian Franc" },
            { "kpw", "Won ng Hilagang Korea" },
            { "krw", "Won ng Timog Korea" },
            { "kwd", "Kuwaiti Dinar" },
            { "kyd", "Dolyar ng Cayman Islands" },
            { "kzt", "Kazakhstani Tenge" },
            { "lak", "Laotian Kip" },
            { "lbp", "Pound ng Lebanon" },
            { "lkr", "Sri Lankan Rupee" },
            { "lrd", "Dolyar ng Liberia" },
            { "lsl", "Lesotho Loti" },
            { "ltl", "Lithuanian Litas" },
            { "lvl", "Latvian Lats" },
            { "lyd", "Libyan Dinar" },
            { "mad", "Moroccan Dirham" },
            { "mdl", "Moldovan Leu" },
            { "mga", "Malagasy Ariary" },
            { "mkd", "Macedonian Denar" },
            { "mmk", "Myanmar Kyat" },
            { "mnt", "Mongolian Tugrik" },
            { "mop", "Macanese Pataca" },
            { "mro", "Mauritanian Ouguiya (1973\u20132017)" },
            { "mru", "Ouguiya ng Mauritania" },
            { "mur", "Mauritian Rupee" },
            { "mvr", "Maldivian Rufiyaa" },
            { "mwk", "Malawian Kwacha" },
            { "mxn", "Piso ng Mexico" },
            { "myr", "Malaysian Ringgit" },
            { "mzn", "Mozambican Metical" },
            { "nad", "Dolyar ng Namibia" },
            { "ngn", "Nigerian Naira" },
            { "nio", "C\u00f3rdoba ng Nicaragua" },
            { "nok", "Norwegian Krone" },
            { "npr", "Nepalese Rupee" },
            { "nzd", "Dolyar ng New Zealand" },
            { "omr", "Omani Rial" },
            { "pab", "Balboa ng Panama" },
            { "pen", "Peruvian Sol" },
            { "pgk", "Papua New Guinean Kina" },
            { "php", "Piso ng Pilipinas" },
            { "pkr", "Pakistani Rupee" },
            { "pln", "Polish Zloty" },
            { "pyg", "Paraguayan Guarani" },
            { "qar", "Qatari Rial" },
            { "ron", "Romanian Leu" },
            { "rsd", "Serbian Dinar" },
            { "rub", "Russian Ruble" },
            { "rwf", "Rwandan Franc" },
            { "sar", "Saudi Riyal" },
            { "sbd", "Dolyar ng Solomon Islands" },
            { "scr", "Seychellois Rupee" },
            { "sdg", "Pound ng Sudan" },
            { "sek", "Swedish Krona" },
            { "sgd", "Dolyar ng Singapore" },
            { "shp", "Saint Helena Pound" },
            { "sit", "Slovenian Tolar" },
            { "skk", "Slovak Koruna" },
            { "sll", "Sierra Leonean Leone" },
            { "sos", "Somali Shilling" },
            { "srd", "Dolyar ng Suriname" },
            { "ssp", "Pound ng Timog Sudan" },
            { "std", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (2018)" },
            { "syp", "Syrian Pound" },
            { "szl", "Swazi Lilangeni" },
            { "thb", "Thai Baht" },
            { "tjs", "Tajikistani Somoni" },
            { "tmt", "Turkmenistani Manat" },
            { "tnd", "Tunisian Dinar" },
            { "top", "Tongan Pa\u02bbanga" },
            { "try", "Turkish Lira" },
            { "ttd", "Dolyar ng Trinidad and Tobago" },
            { "twd", "Dolyar ng New Taiwan" },
            { "tzs", "Tanzanian Shilling" },
            { "uah", "Ukrainian Hryvnia" },
            { "ugx", "Ugandan Shilling" },
            { "usd", "Dolyar ng US" },
            { "uyu", "Piso ng Uruguay" },
            { "uzs", "Uzbekistan Som" },
            { "veb", "Venezuelan Bol\u00edvar (1871\u20132008)" },
            { "vef", "Bol\u00edvar ng Venezuela (2008\u20132018)" },
            { "ves", "Bol\u00edvar ng Venezuela" },
            { "vnd", "Vietnamese Dong" },
            { "vuv", "Vanuatu Vatu" },
            { "wst", "Samoan Tala" },
            { "xaf", "CFA Franc BEAC" },
            { "xcd", "Dolyar ng Silangang Caribbean" },
            { "xof", "CFA Franc ng Kanlurang Africa" },
            { "xpf", "CFP Franc" },
            { "xxx", "Hindi Kilalang Pera" },
            { "yer", "Yemeni Rial" },
            { "zar", "Rand ng Timog Africa" },
            { "zmk", "Zambian Kwacha (1968\u20132012)" },
            { "zmw", "Zambian Kwacha" },
        };
        return data;
    }
}

==> openjdk15-15.0.9_0+release+server.darwin_24.x86_64.tbz2: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fil.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fil extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "\u20b1" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "United Arab Emirates Dirham" },
            { "afn", "Afghan Afghani" },
            { "all", "Albanian Lek" },
            { "amd", "Armenian Dram" },
            { "ang", "Antillean Guilder ng Netherlands" },
            { "aoa", "Angolan Kwanza" },
            { "ars", "Piso ng Argentina" },
            { "aud", "Dolyar ng Australya" },
            { "awg", "Florin ng Aruba" },
            { "azn", "Azerbaijani Manat" },
            { "bam", "Bosnia-Herzegovina Convertible Mark" },
            { "bbd", "Dolyar ng Barbados" },
            { "bdt", "Bangladeshi Taka" },
            { "bgn", "Bulgarian Lev" },
            { "bhd", "Bahraini Dinar" },
            { "bif", "Burundian Franc" },
            { "bmd", "Dolyar ng Bermuda" },
            { "bnd", "Dolyar ng Brunei" },
            { "bob", "Boliviano ng Bolivia" },
            { "brl", "Real ng Barzil" },
            { "bsd", "Dolyar ng Bahamas" },
            { "btn", "Bhutanese Ngultrum" },
            { "bwp", "Botswanan Pula" },
            { "byn", "Belarusian Ruble" },
            { "byr", "Belarusian Ruble (2000\u20132016)" },
            { "bzd", "Dolyar ng Belize" },
            { "cad", "Dolyar ng Canada" },
            { "cdf", "Congolese Franc" },
            { "chf", "Swiss Franc" },
            { "clp", "Piso ng Chile" },
            { "cnh", "Chinese Yuan (offshore)" },
            { "cny", "Chinese Yuan" },
            { "cop", "Piso ng Colombia" },
            { "crc", "Col\u00f3n ng Costa Rica" },
            { "cuc", "Convertible na Piso ng Cuba" },
            { "cup", "Piso ng Cuba" },
            { "cve", "Cape Verdean Escudo" },
            { "czk", "Czech Republic Koruna" },
            { "dem", "Deutsche Marks" },
            { "djf", "Djiboutian Franc" },
            { "dkk", "Danish Krone" },
            { "dop", "Piso ng Dominican" },
            { "dzd", "Algerian Dinar" },
            { "eek", "Estonian Kroon" },
            { "egp", "Egyptian Pound" },
            { "ern", "Eritrean Nakfa" },
            { "etb", "Ethiopian Birr" },
            { "eur", "Euro" },
            { "fjd", "Dolyar ng Fiji" },
            { "fkp", "Pound ng Falkland Islands" },
            { "frf", "French Franc" },
            { "gbp", "British Pound" },
            { "gel", "Georgian Lari" },
            { "ghs", "Ghanaian Cedi" },
            { "gip", "Gibraltar Pound" },
            { "gmd", "Gambian Dalasi" },
            { "gnf", "Guinean Franc" },
            { "gtq", "Quetzal ng Guatemala" },
            { "gyd", "Dolyar ng Guyanese" },
            { "hkd", "Dolyar ng Hong Kong" },
            { "hnl", "Lempira ng Honduras" },
            { "hrk", "Croatian Kuna" },
            { "htg", "Gourde ng Haiti" },
            { "huf", "Hungarian Forint" },
            { "idr", "Indonesian Rupiah" },
            { "ils", "Israeli New Sheqel" },
            { "inr", "Indian Rupee" },
            { "iqd", "Iraqi Dinar" },
            { "irr", "Iranian Rial" },
            { "isk", "Icelandic Kr\u00f3na" },
            { "jmd", "Dolyar ng Jamaica" },
            { "jod", "Jordanian Dinar" },
            { "jpy", "Japanese Yen" },
            { "kes", "Kenyan Shilling" },
            { "kgs", "Kyrgystani Som" },
            { "khr", "Cambodian Riel" },
            { "kmf", "Comorian Franc" },
            { "kpw", "Won ng Hilagang Korea" },
            { "krw", "Won ng Timog Korea" },
            { "kwd", "Kuwaiti Dinar" },
            { "kyd", "Dolyar ng Cayman Islands" },
            { "kzt", "Kazakhstani Tenge" },
            { "lak", "Laotian Kip" },
            { "lbp", "Pound ng Lebanon" },
            { "lkr", "Sri Lankan Rupee" },
            { "lrd", "Dolyar ng Liberia" },
            { "lsl", "Lesotho Loti" },
            { "ltl", "Lithuanian Litas" },
            { "lvl", "Latvian Lats" },
            { "lyd", "Libyan Dinar" },
            { "mad", "Moroccan Dirham" },
            { "mdl", "Moldovan Leu" },
            { "mga", "Malagasy Ariary" },
            { "mkd", "Macedonian Denar" },
            { "mmk", "Myanmar Kyat" },
            { "mnt", "Mongolian Tugrik" },
            { "mop", "Macanese Pataca" },
            { "mro", "Mauritanian Ouguiya (1973\u20132017)" },
            { "mru", "Ouguiya ng Mauritania" },
            { "mur", "Mauritian Rupee" },
            { "mvr", "Maldivian Rufiyaa" },
            { "mwk", "Malawian Kwacha" },
            { "mxn", "Piso ng Mexico" },
            { "myr", "Malaysian Ringgit" },
            { "mzn", "Mozambican Metical" },
            { "nad", "Dolyar ng Namibia" },
            { "ngn", "Nigerian Naira" },
            { "nio", "C\u00f3rdoba ng Nicaragua" },
            { "nok", "Norwegian Krone" },
            { "npr", "Nepalese Rupee" },
            { "nzd", "Dolyar ng New Zealand" },
            { "omr", "Omani Rial" },
            { "pab", "Balboa ng Panama" },
            { "pen", "Peruvian Sol" },
            { "pgk", "Papua New Guinean Kina" },
            { "php", "Piso ng Pilipinas" },
            { "pkr", "Pakistani Rupee" },
            { "pln", "Polish Zloty" },
            { "pyg", "Paraguayan Guarani" },
            { "qar", "Qatari Rial" },
            { "ron", "Romanian Leu" },
            { "rsd", "Serbian Dinar" },
            { "rub", "Russian Ruble" },
            { "rwf", "Rwandan Franc" },
            { "sar", "Saudi Riyal" },
            { "sbd", "Dolyar ng Solomon Islands" },
            { "scr", "Seychellois Rupee" },
            { "sdg", "Pound ng Sudan" },
            { "sek", "Swedish Krona" },
            { "sgd", "Dolyar ng Singapore" },
            { "shp", "Saint Helena Pound" },
            { "sit", "Slovenian Tolar" },
            { "skk", "Slovak Koruna" },
            { "sll", "Sierra Leonean Leone" },
            { "sos", "Somali Shilling" },
            { "srd", "Dolyar ng Suriname" },
            { "ssp", "Pound ng Timog Sudan" },
            { "std", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (1977\u20132017)" },
            { "stn", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (2018)" },
            { "syp", "Syrian Pound" },
            { "szl", "Swazi Lilangeni" },
            { "thb", "Thai Baht" },
            { "tjs", "Tajikistani Somoni" },
            { "tmt", "Turkmenistani Manat" },
            { "tnd", "Tunisian Dinar" },
            { "top", "Tongan Pa\u02bbanga" },
            { "try", "Turkish Lira" },
            { "ttd", "Dolyar ng Trinidad and Tobago" },
            { "twd", "Dolyar ng New Taiwan" },
            { "tzs", "Tanzanian Shilling" },
            { "uah", "Ukrainian Hryvnia" },
            { "ugx", "Ugandan Shilling" },
            { "usd", "Dolyar ng US" },
            { "uyu", "Piso ng Uruguay" },
            { "uzs", "Uzbekistan Som" },
            { "veb", "Venezuelan Bol\u00edvar (1871\u20132008)" },
            { "vef", "Bol\u00edvar ng Venezuela (2008\u20132018)" },
            { "ves", "Bol\u00edvar ng Venezuela" },
            { "vnd", "Vietnamese Dong" },
            { "vuv", "Vanuatu Vatu" },
            { "wst", "Samoan Tala" },
            { "xaf", "CFA Franc BEAC" },
            { "xcd", "Dolyar ng Silangang Caribbean" },
            { "xof", "CFA Franc ng Kanlurang Africa" },
            { "xpf", "CFP Franc" },
            { "xxx", "Hindi Kilalang Pera" },
            { "yer", "Yemeni Rial" },
            { "zar", "Rand ng Timog Africa" },
            { "zmk", "Zambian Kwacha (1968\u20132012)" },
            { "zmw", "Zambian Kwacha" },
        };
        return data;
    }
}
